
# libmseed - The miniSEED library

The miniSEED library provides a framework for manipulation of SEED
data records, a format for commonly used for seismological time series
and related data.  The library includes the functionality to read and
write data records, in addition to reconstructing time series from
multiple records.

The library should work in Unix-like, Windows and potentially other
environments.

## Documentation

The [Documentation](https://earthscope.github.io/libmseed) provides an
overview of using the library, a tutorial and function level details.

## License

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Copyright (C) 2024 Chad Trabant, EarthScope Data Services
